pub fn eth_call<T: Config>(
dest: H160,
value: U256,
weight_limit: Weight,
eth_gas_limit: U256,
data: Vec<u8>,
transaction_encoded: Vec<u8>,
effective_gas_price: U256,
encoded_len: u32,
authorization_list: Vec<AuthorizationListEntry>,
)Expand description
Same as [Self::call], but intended to be dispatched only
by an EVM transaction through the EVM compatibility layer.
Parameters
dest: The Ethereum address of the account to be calledvalue: The balance to transfer from theoriginto the newly created contract.weight_limit: The gas limit used to derive the transaction weight for transaction paymenteth_gas_limit: The Ethereum gas limit governing the resource usage of the executiondata: The input data to pass to the contract constructor.transaction_encoded: The RLP encoding of the signed Ethereum transaction, represented as crate::evm::TransactionSigned, provided by the Ethereum wallet. This is used for building the Ethereum transaction root.effective_gas_price: the price of a unit of gasencoded_len: the byte code size of theeth_transactextrinsicauthorization_list: EIP-7702 authorization tuples to process before execution
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::eth_call.